<?php
/**
 * Copyright (©) 2020 Pinpoint Designs LTD. All right's reserved.
 *
 * @category    Pinpoint
 * @copyright   Copyright (c) 2020 Pinpoint Designs. (http://www.pinpointdesigns.co.uk)
 * @author      Daniel Cuevas <daniel@pinpointdesigns.co.uk>
 */

namespace Pinpoint\CarouselManager\Controller\Adminhtml\Slide;

use Magento\Framework\Exception\LocalizedException;
use Pinpoint\CarouselManager\Model\SlideRepository;

/**
 * Class SaveSlide
 */
class Delete extends \Magento\Backend\App\Action
{

    protected $dataPersistor;
    /**
     * @var \Magento\Framework\Controller\Result\JsonFactory
     */
    private $resultJsonFactory;
    /**
     * @var SlideRepository
     */
    private $slideRepository;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\App\Request\DataPersistorInterface $dataPersistor
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory,
        SlideRepository $slideRepository,
        \Magento\Framework\App\Request\DataPersistorInterface $dataPersistor
    ) {
        $this->dataPersistor = $dataPersistor;
        $this->resultJsonFactory = $resultJsonFactory;
        $this->slideRepository = $slideRepository;
        parent::__construct($context);
    }

    /**
     * Save action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Backend\Model\View\Result\Redirect $resultRedirect */
        $resultRedirect = $this->resultRedirectFactory->create();

        $data = $this->getRequest()->getParams();
        if ($data) {
            $slideId = $data['slide_id'];
            $carouselId = $data['carousel_id'];

            try {
                $this->slideRepository->deleteById($slideId);
                $this->messageManager->addSuccessMessage(__('You deleted the Slide.'));
            } catch (LocalizedException $e) {
                $this->messageManager->addErrorMessage($e->getMessage());
            } catch (\Exception $e) {
                $this->messageManager->addExceptionMessage($e, __('Something went wrong while deleting the slide.'));
            }
        }

        return $resultRedirect->setPath('*/carousel/edit', ['carousel_id' => $carouselId]);
    }
}