<?php
/**
 * Copyright ©  All rights reserved.
 * See COPYING.txt for license details.
 */
declare(strict_types=1);

namespace Pinpoint\CarouselManager\Model;

use Magento\Framework\Api\DataObjectHelper;
use Pinpoint\CarouselManager\Api\Data\SlideCtaInterface;
use Pinpoint\CarouselManager\Api\Data\SlideCtaInterfaceFactory;

class SlideCta extends \Magento\Framework\Model\AbstractModel
{

    protected $slidectaDataFactory;

    protected $dataObjectHelper;

    protected $_eventPrefix = 'pinpoint_carouselmanager_slidecta';

    /**
     * @param \Magento\Framework\Model\Context $context
     * @param \Magento\Framework\Registry $registry
     * @param SlideCtaInterfaceFactory $slidectaDataFactory
     * @param DataObjectHelper $dataObjectHelper
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\SlideCta $resource
     * @param \Pinpoint\CarouselManager\Model\ResourceModel\SlideCta\Collection $resourceCollection
     * @param array $data
     */
    public function __construct(
        \Magento\Framework\Model\Context $context,
        \Magento\Framework\Registry $registry,
        SlideCtaInterfaceFactory $slidectaDataFactory,
        DataObjectHelper $dataObjectHelper,
        \Pinpoint\CarouselManager\Model\ResourceModel\SlideCta $resource,
        \Pinpoint\CarouselManager\Model\ResourceModel\SlideCta\Collection $resourceCollection,
        array $data = []
    ) {
        $this->slidectaDataFactory = $slidectaDataFactory;
        $this->dataObjectHelper = $dataObjectHelper;
        parent::__construct($context, $registry, $resource, $resourceCollection, $data);
    }

    /**
     * Retrieve slidecta model with slidecta data
     * @return SlideCtaInterface
     */
    public function getDataModel()
    {
        $slidectaData = $this->getData();
        
        $slidectaDataObject = $this->slidectaDataFactory->create();
        $this->dataObjectHelper->populateWithArray(
            $slidectaDataObject,
            $slidectaData,
            SlideCtaInterface::class
        );
        
        return $slidectaDataObject;
    }
}

